@@ -8,3 +8,14 @@ test_that("Inputs of (no preamble)", {
   expect_equal(inputs_of("extract/road-congestion.tex", exclude.preamble = FALSE, append.tex = FALSE),
                c("tex/preamble", "tex/MEL-commutes-map-legend-tbl"))
 })
+
+
+test_that("Includes x", {
+  inputs_of_ <- inputs_of("inputs-of/inputs-includes.tex",
+                          exclude.preamble = FALSE,
+                          append.tex = FALSE)
+  expect_equal(inputs_of_, 
+               c("preamble",
+                 "Mid-document.tex",
+                 "XY"))
+})
\ No newline at end of file
