@@ -7,7 +7,7 @@ test_that("Bills of Parliament", {
 })
 
 test_that("Duplicate fields noticed", {
-  expect_error(fread_bib("./validate-bib/dup_fields.bib"), 
+  expect_error(any_bib_duplicates("./validate-bib/dup_fields.bib"), 
                regexp = "Duplicate fields found in RMS2010Hunter")
 })
 
@@ -18,7 +18,17 @@ test_that("Duplicate entries error", {
                regexp = "[Dd]uplicate entries in bibliography")
 })
 
+test_that("Duplicate entry keys", {
+  expect_error(any_bib_duplicates("./validate-bib/dup-key.bib"),
+               regexp = "Duplicate bib key used")
+})
+
 test_that("Broken fields detected", {
   expect_error(validate_bibliography(file = "./validate-bib/field-broken-over2lines.bib"), 
                regexp = "which is neither a key, nor field")
 })
+
+test_that("Near-duplicate authors", {
+  expect_error(any_bib_duplicates("validate-bib/near-dup-authors.bib", report2console),
+               regexp = "Same author used with inconsistent.*case")
+})
